@@ -19,6 +19,9 @@ import datetime
 import time
 
 import logging
+from pyf.componentized.configuration.keys import SimpleKey, CompoundKey
+from pyf.componentized.configuration.fields import SingleSelectField, InputField,\
+    TextAreaField
 log = logging.getLogger()
 
 def buftee(iterable, n=2):
@@ -41,6 +44,22 @@ def buftee(iterable, n=2):
 
 class RMLPDFWriter(MultipleFileWriter):
     name = "rmlpdfwriter"
+    
+    configuration = [SimpleKey('encoding', default="UTF-8"),
+                     SimpleKey('target_filename', default="filename.pdf"),
+                     CompoundKey('template',
+                                 text_value='template',
+                                 text_as_cdata=True,
+                                 attributes={'type': 'type',
+                                             'module': 'module'},
+                                 fields=[SingleSelectField('type',
+                                                           label='Template Type',
+                                                           values=['embedded', 'plugin'],
+                                                           default='embedded'),
+                                         InputField('module',
+                                                    label='Plugin Module',
+                                                    help_text='Use only for type "plugin"'),
+                                         TextAreaField('template', classname="xmlcode")])]
 
     def __init__(self, config_node, component_id):
         """Initialize a new RMLPDFWriter
@@ -58,12 +77,11 @@ class RMLPDFWriter(MultipleFileWriter):
                                                          'report.pdf')
 
         self.template = self.get_template()
-
-
+        
     def get_template(self):
-        template_node = self.config_node.find('template')
+        template_node = self.get_config_key('template')
         template_type = template_node.get('type', 'embedded')
-
+        
         if template_type == 'plugin':
             template_module = template_node.get('module')
             return ReportTemplate(
@@ -72,9 +90,10 @@ class RMLPDFWriter(MultipleFileWriter):
                            "static/templates/" + template_node.text.strip() + ".xml"
                        )
                    )
+            
         elif template_type == 'embedded':
-            return ReportTemplate(template_node.text.strip())
-
+            return ReportTemplate(template_node.get('template'))
+        
         else:
             raise NotImplementedError, "Template type %s is not handled." % \
                                                                 template_type
